@@ -44,7 +44,6 @@ int alphabetSize[15] = {
 		8, 8, 8, 8, 8, 8, 8, 8, 8, 8, 7, 4, 8, 4, 7
 	};
 int percentPosition[4] = { 13, 21, 29, 37 };
-int timePosition[5] = { 12, 19, 26, 30, 37 };
 
 #define BATTERY_IMAGE_X 14
 #define BATTERY_IMAGE_Y 4
@@ -601,259 +600,6 @@ void initializeWindow(int argc, char** argv,
 	XFlush(mainDisplay);
 }
 
-/*
- * Draw the slider bar. The slider bar has two
- * colors. The bottom side shows the percent left
- * of the battery's charge (greenPixel) and
- * the top shows the rest (redPixel)
- */
-void DrawIndicator(Window win)
-{
-	int points;
-	if (state.percent < 0) {
-		/* clear previously drawn label */
-		XClearArea(
-			mainDisplay,
-			win,
-			2,
-			4,
-			7,
-			42,
-			False
-			);
-		return;
-	}
-	points = (state.percent==100) ? 42 : (42.0/100 * state.percent);
-	/* set green color */
-	mainGCV.foreground = greenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	/* draw the bottom part of the indicator */
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		5,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = darkgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		8,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = semidarkgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		7,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = bitdarkgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		6,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = lightgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		2,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = semilightgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		3,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	mainGCV.foreground = bitlightgreenPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		4,
-		4+42-points, /*4,*/
-		1,
-		points
-		);
-	/* set red color */
-	mainGCV.foreground = redPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	/* draw right side of the indicator */
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		3,
-		4, /*4+points,*/
-		4,
-		42-points
-		);
-	mainGCV.foreground = lightredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		8,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-	mainGCV.foreground = semilightredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		7,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-	mainGCV.foreground = bitlightredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		6,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-	mainGCV.foreground = darkredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		2,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-	mainGCV.foreground = semidarkredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		3,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-	mainGCV.foreground = bitdarkredPixel;
-	XChangeGC(
-		mainDisplay,
-		mainGC,
-		GCForeground,
-		&mainGCV
-		);
-	XFillRectangle(
-		mainDisplay,
-		win,
-		mainGC,
-		4,
-		4, /*4+points,*/
-		1,
-		42-points
-		);
-}
-
 void DrawBattery( Window win )
 {
 	Pixel theColor;
@@ -963,62 +709,15 @@ void DrawPercent(Window win)
 		);
 }
 
-void DrawTime(Window win)
-{
-	int tmp[5];
-	int i;
-	int firstDigit = 0;
-	int time_left;
-	if ( (state.time_left > 0) && (state.system_time) )
-		time_left = state.time_left;
-	else
-		time_left = state.time_estimate;
-	if ( time_left > 0 ) {
-		if ( time_left / 60 / 10 % 10 ) {
-			tmp[0] = time_left / 60 / 10 % 10;
-			firstDigit = 1;
-		} else
-			tmp[0] = 10;
-		if ( firstDigit || (time_left / 60 % 10) )
-			tmp[1] = time_left / 60 % 10;
-		else
-			tmp[1] = 10;
-		tmp[2] = 11;
-		tmp[3] = time_left % 60 / 10;
-		tmp[4] = time_left % 60 % 10;
-	} else {
-		tmp[0] = 10;
-		tmp[1] = 10;
-		tmp[2] = 13;
-		tmp[3] = 10;
-		tmp[4] = 10;
-	}
-	for (i=0; i<5; ++i)
-	XCopyArea(
-		mainDisplay,
-		alphabetXpm.pixmap,
-		win,
-		mainGC,
-		alphabetPosition[tmp[i]],
-		0,
-		alphabetSize[tmp[i]],
-		11,
-		timePosition[i],
-		33
-		);
-}
+
 
 /* This requests redrawing of all elements */
 void Redraw()
 {
-	DrawIndicator(mainWindow);
 	DrawBattery(mainWindow);
 	DrawPercent(mainWindow);
-	DrawTime(mainWindow);
-	DrawIndicator(iconWindow);
 	DrawBattery(iconWindow);
 	DrawPercent(iconWindow);
-	DrawTime(iconWindow);
 }
 
 /*
